FlutterEmbedView class

Constructors

FlutterEmbedView({String? id, String? classes, Styles? styles, ViewConstraints? constraints, Component? loader, Widget? widget, Key? key})
const
FlutterEmbedView.deferred({String? id, String? classes, Styles? styles, ViewConstraints? constraints, Component? loader, Future<void>? loadLibrary, Widget builder()?, Key? key})
const

Properties

builder Widget Function()?
final
classes String?
final
constraints ViewConstraints?
final
hashCode int
The hash code for this object.
no setterinherited
id String?
final
key → Key?
Controls how one component replaces another component in the tree.
finalinherited
loader → Component?
final
loadLibrary Future<void>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
styles → Styles?
final
widget Widget?
final

Methods

createElement() → Element
Creates a StatefulElement to manage this component's location in the tree.
inherited
createState() → State<StatefulComponent>
Creates the mutable state for this component at a given location in the tree.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

preload() Future<void>