FlutterEmbedView class
Constructors
-
FlutterEmbedView({String? id, String? classes, Styles? styles, ViewConstraints? constraints, Component? loader, Widget? widget, Key? key})
-
const
-
FlutterEmbedView.deferred({String? id, String? classes, Styles? styles, ViewConstraints? constraints, Component? loader, Future<void>? loadLibrary, Widget builder()?, Key? key})
-
const
Methods
-
createElement()
→ Element
-
Creates a
StatefulElement to manage this component's location in the tree.
inherited
-
createState()
→ State<StatefulComponent>
-
Creates the mutable state for this component at a given location in the tree.
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited